@@ -1,4 +1,4 @@
-from enum import Enum
+from ..progress import ProgressDataModel
 from pydantic.main import BaseModel
 from ....messages.types import  PROVIDE, PROVIDE_DONE, PROVIDE_PROGRESS, RESERVE_PROGRESS
 from ....messages.base import MessageDataModel, MessageMetaExtensionsModel, MessageMetaModel, MessageModel
@@ -15,15 +15,6 @@ class MetaModel(MessageMetaModel):
     extensions: Optional[MetaExtensionsModel]
 
 
-class ProgressLevel(str, Enum):
-    INFO = "INFO"
-    DEBUG = "DEBUG"
-
-
-class DataModel(MessageDataModel):
-    level: ProgressLevel
-    message: str
-
 class ReserveProgressMessage(MessageModel):
-    data: DataModel
+    data: ProgressDataModel
     meta: MetaModel
\ No newline at end of file
