@@ -50,11 +50,12 @@ class Channel:
 class WebsocketPostman(BasePostman):
     type = "websocket"
 
-    def __init__(self, port= None, protocol = None, host= None, auth= None, **kwargs) -> None:
+    def __init__(self, client, port= None, protocol = None, host= None, auth= None, **kwargs) -> None:
+        super().__init__(client, **kwargs)
         self.token = auth["token"]
-        self.port = port
+        self.port = port or client.config.port
         self.protocol = protocol
-        self.host = host
+        self.host = host or client.config.host
         self.connection = None      
         self.channel = None         
         self.callback_queue = ''
@@ -74,15 +75,20 @@ class WebsocketPostman(BasePostman):
         self.progresses = {}  # Also queues
         self.pending = []
 
+        self.receiving_task = None
+        self.sending_task = None
+        self.callback_task = None
+
 
         self.assign_routing = "assignation_request"
-        super().__init__(**kwargs)
 
     async def connect(self):
         self.callback_queue = asyncio.Queue()
         self.progress_queue = asyncio.Queue()
         self.send_queue = asyncio.Queue()
 
+        
+
 
         self.tasks = []
 
