@@ -60,6 +60,8 @@ class BaseProvider(Hookable):
 
 
     def template(self, node: Node, policy: PodPolicy = MultiplePodPolicy(), auto_provide=False, on_provide=None,  on_unprovide=None, bypass_shrink=False, bypass_expand=False, **implementation_details):
+        console.print("[blue] Registered to Provide")
+        console.print(node)
 
         def real_decorator(function_or_actor):
             assert callable(function_or_actor) or issubclass(function_or_actor, Actor), "Please only decorate functions or subclasses of Actor"
@@ -117,8 +119,6 @@ class BaseProvider(Hookable):
                 console.log("Is Function. Creating Node and Wrapping")
                 node = createNodeFromFunction(function_or_actor, allow_empty_doc=allow_empty_doc, widgets=widgets)
 
-            console.log("Created Node",node)
-                
             # We pass this down to our truly template wrapper that takes the node and transforms it
             template_wrapper = self.template(node, **implementation_details)
             function = template_wrapper(function_or_actor)
