@@ -90,7 +90,7 @@ def parseFunctionToDict(function: Callable, widgets: dict = {}, allow_empty_doc=
     if docstring.returns:
         return_description = docstring.returns.description
         seperated_list = return_description.split(",")
-        assert len(returns) == len(seperated_list), "Length of Description and Returns not Equal: If you provide a Return Annotation make sure you seperate the description for each port with ','"
+        assert len(returns) == len(seperated_list), f"Length of Description and Returns not Equal: If you provide a Return Annotation make sure you seperate the description for each port with ',' Return Description {return_description} Returns: {returns}"
         for index, doc in enumerate(seperated_list):
             returns[index].description = doc
 
