@@ -177,7 +177,7 @@ class ArnheimModel(BaseModel, metaclass=ArnheimModelMeta):
             raise ArnheimModelConfigurationError(f"Make soure your Model {cls.__name__}overwrites Meta identifier: {e}")
 
         from bergen.registries.ward import get_ward_registry
-        return get_ward_registry().getWardForIdentifier(identifier=identifier)
+        return get_ward_registry().get_ward(identifier=identifier)
 
     @classmethod
     def getMeta(cls):
