@@ -38,7 +38,7 @@ async def expandInputs(node: Node, args: list, kwargs: dict) -> dict:
 
         if port.TYPENAME == PortTypes.MODEL_KWARG_PORT:
             modelClass = get_current_matcher().getModelForIdentifier(identifier=port.identifier)
-            instance =  await modelClass.asyncs.get(id=args[port.key])
+            instance =  await modelClass.asyncs.get(id=kwargs[port.key])
             expanded_kwargs[port.key] = instance
         else:
             expanded_kwargs[port.key] = kwargs[port.key]
@@ -78,7 +78,6 @@ async def shrinkInputs(node: Node, args: list, kwargs: dict) -> Tuple[dict, dict
 
     shrinked_args = []
     for arg, port in zip(args, node.args):
-        print(port)
         if port.TYPENAME == PortTypes.MODEL_ARG_PORT:
             instance = arg
             if isinstance(instance, ArnheimModel):
