@@ -46,7 +46,7 @@ class BaseWard(ABC):
             return 
         except:
             console.print_exception()
-            raise ConnectionError(f"Connection to {self.host}:{self.port} on {self.port} Failed")
+            raise ConnectionError(f"Ward {self.distinct}: Connection to {self.host}:{self.port} on {self.port} Failed")
         
 
 
