@@ -1,5 +1,5 @@
 from abc import ABC
-from bergen.schema import DataPoint
+from bergen.schema import DataPoint, WardSettings
 
 from gql.gql import gql
 from gql.transport.requests import RequestsHTTPTransport
@@ -23,8 +23,8 @@ class BaseGraphQLWard(BaseWard, ABC):
     can_subscribe = False
     
 
-    def __init__(self, client, point: DataPoint, loop=None) -> None:
-        super().__init__(client, point, loop=loop)
+    def __init__(self, client, settings: WardSettings, loop=None) -> None:
+        super().__init__(client, settings, loop=loop)
         self._graphql_endpoint = f"{self.protocol}://{self.host}:{self.port}/graphql"
         self._headers = {"Authorization": f"Bearer {self.token}"}
 
